ReactionStatus

reactify.reaction.ReactionStatus
See theReactionStatus companion trait

ReactionStatus is utilized during the propagation of a fired value against a Reactive. This value may be returned by a Reaction or set via status on the Reactive (on the same thread while the fired value is propagating)

Attributes

Companion
trait
Graph
Supertypes
class Object
trait Matchable
class Any
Self type

Members list

Type members

Classlikes

case object Continue extends ReactionStatus

Continue propagation

Continue propagation

Attributes

Supertypes
trait Singleton
trait Product
trait Mirror
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
Self type
Continue.type
case object Stop extends ReactionStatus

Stop propagation

Stop propagation

Attributes

Supertypes
trait Singleton
trait Product
trait Mirror
trait Serializable
trait Product
trait Equals
class Object
trait Matchable
class Any
Show all
Self type
Stop.type