reactify.transaction
package reactify.transaction
Members list
Type members
Classlikes
class Transaction
Attributes
- Companion
- object
- Supertypes
-
class Objecttrait Matchableclass Any
object Transaction
Transaction allows access to undo, redo, revert, and commit changes to Vars
Transaction allows access to undo, redo, revert, and commit changes to Vars
Attributes
- Companion
- class
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
Transaction.type
TransactionChange represents the transactional changes for a single Var in a Transaction
TransactionChange represents the transactional changes for a single Var in a Transaction
Value parameters
- apply
-
applies the changes applied during the transaction
- unapply
-
reverts the changes applied during the transaction
Attributes
- Supertypes
-
trait Serializabletrait Producttrait Equalsclass Objecttrait Matchableclass AnyShow all
In this article