Transaction

reactify.transaction.Transaction
See theTransaction companion class
object Transaction

Transaction allows access to undo, redo, revert, and commit changes to Vars

Attributes

Companion
class
Graph
Supertypes
class Object
trait Matchable
class Any
Self type

Members list

Value members

Concrete methods

def active: Boolean

True if a Transaction is currently active on the current thread

True if a Transaction is currently active on the current thread

Attributes

def apply(f: => Unit): Transaction

Creates a new Transaction if one isn't already active or re-uses an existing one if a Transaction is already in-progress for this thread.

Creates a new Transaction if one isn't already active or re-uses an existing one if a Transaction is already in-progress for this thread.

Value parameters

f

the function to run within a Transaction

Attributes

Returns

Transaction

def change[T](owner: Var[T], oldFunction: () => T, newFunction: () => T): Boolean

Called when the value of a Var changes

Called when the value of a Var changes

Attributes