reactify.reaction.ReactionStatus
See theReactionStatus companion trait
object ReactionStatus
ReactionStatus is utilized during the propagation of a fired value against a Reactive. This value may be returned by a Reaction or set via status on the Reactive (on the same thread while the fired value is propagating)
Attributes
- Companion
- trait
- Graph
-
- Supertypes
-
class Objecttrait Matchableclass Any
- Self type
-
ReactionStatus.type
Members list
In this article