reactify.transaction.Transaction
See theTransaction companion class
Transaction allows access to undo, redo, revert, and commit changes to Vars
Attributes
-
Companion
-
class
-
Graph
-
-
Supertypes
-
class Object
trait Matchable
class Any
-
Self type
-
Members list
True if a Transaction is currently active on the current thread
True if a Transaction is currently active on the current thread
Attributes
Creates a new Transaction if one isn't already active or re-uses an existing one if a Transaction is already in-progress for this thread.
Creates a new Transaction if one isn't already active or re-uses an existing one if a Transaction is already in-progress for this thread.
Value parameters
-
f
-
the function to run within a Transaction
Attributes
-
Returns
-
Transaction
Called when the value of a Var changes
Called when the value of a Var changes
Attributes